@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v. 2.1.2
+  knetfilter v. 2.2.0
 
   Copyright (C) 2001 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -96,6 +96,10 @@ public:
   KProcess manglepolrules;
   KProcess tcpmssrules;
   // KProcess stop_tcpmssrules;
+  KProcess addshaperqdisc;
+  KProcess addshaperrootclass;
+  KProcess addshapersubclass;
+  KProcess addshaperfilter;
 
 public slots:
   void addRule();
@@ -154,14 +158,12 @@ public slots:
   void NMap();
   void portDump(KProcess *, char *, int);
 
-
   /* list rules functions */
   void iptablesRules();
   void closeiptablesRules();
   void startlistRules();
   void listRulesDone();
   void listRules(KProcess *, char *, int);
-
   void interfaceActivated(int);
   void interfacenrActivated(int);
   void stateActivated(int);
@@ -170,6 +172,17 @@ public slots:
   void flagsActivated(int);
   void polchainActivated(int);
 
+  /* traffic shaper functions */
+  void trafficShaper();
+  void closeshaperRules();
+  void startshaperRules();
+  void shaperRules(KProcess *, char *, int);
+  void shaperinterfaceActivated(int);
+  void shaperinterfacenrActivated(int);
+  void shaperQdisc();
+  void shaperClass();
+  void shaperSubclass();
+
 
   /* chain policy options */
   void polRules();
@@ -309,7 +322,16 @@ private:
   QLineEdit *firsttcpmssNetMask;
   QLineEdit *secondtcpmssNet;
   QLineEdit *secondtcpmssNetMask;
-
+  QLineEdit *shaperMark;
+  QLineEdit *shaperglobalBand;
+  QLineEdit *shaperrateBand;
+  QLineEdit *shaperqdiscHandle;
+  QLineEdit *shaperrootclassId;
+  QLineEdit *shaperrootclassWeight;
+  QLineEdit *shaperrootclassPrio;
+  QLineEdit *shapersubclassId;
+  QLineEdit *shapersubclassWeight;
+  QLineEdit *shapersubclassPrio;
 
   KNFWidget *polList;
   KNFWidget *markList;
@@ -322,12 +344,14 @@ private:
   KNFWidget *mapList;
   KNFWidget *masqWin;
   KNFWidget *tcpmssList;
+  KNFWidget *shaperList;
   QListBox *polBox;
   QListBox *natpolBox;
   QListBox *manglepolBox;
   QListBox *masqBox;
   QListBox *dumpBox;
   QListBox *mapBox;
+  QListBox *shaperBox;
   QComboBox *interface;
   QComboBox *interfacenr;
   QComboBox *chain;
@@ -362,12 +386,14 @@ private:
   QComboBox *nmapoptions;
   QComboBox *nmapoptions_icmp;
   QComboBox *tcpmsschain;
-  QCheckBox *mapopt1;
-  QCheckBox *mapopt2;
-  QCheckBox *mapopt3;
+  QComboBox *shaperinterface;
+  QComboBox *shaperinterfacenr;
   QCheckBox *manglelog1;
   QCheckBox *manglelog2;
   QCheckBox *manglelog3;
+  QCheckBox *shaperqdisc;
+  QCheckBox *shaperclass;
+  QCheckBox *shapersubclass;
 
   /* the menubar, toolbar statusbar and marktoolbar*/
   KMenuBar *menubar;
@@ -433,10 +459,19 @@ private:
   char *log3;
   char *tcpmssChoice;
   char *tcpmssruleaction;
-   
+  char *shaperinterfaceChoice;
+  int shaperinterfacenrChoice;
+  char *shaperinterfaceChoicedmp;
+  char *shaperinterfacenrChoicedmp;
+  int qdisc_exec;
+  int class_exec;
+  int subclass_exec;
+
+  // for the toolbar
   int add;
   int del; 
 
+  int system_has_tc;
 /*-------- REMOVE LATER --------
   int polcheck;
   int rulecheck;
