@@ -1,8 +1,8 @@
   /*
 
-  knetfilter v 2.1.1
+  knetfilter v 2.2.0
 
-  Copyright (C) 2000 Luigi Genoni
+  Copyright (C) 2001 Luigi Genoni
   		     venom@DarkStar.sns.it
   */
   
@@ -25,7 +25,7 @@ void knetfilter::startpolRules() {
     polrules.clearArguments();
     
     polrules << "iptables" << "-P" << polchainChoice << chainpolicyChoice;
-    printf("%s %s\n",polchainChoice,chainpolicyChoice);
+
     bool success=polrules.start(KProcess::NotifyOnExit,
 				KProcess::AllOutput);
     if (success)     
@@ -475,10 +475,9 @@ void knetfilter::NMap(){
       
       mapList->show();
       setView(mapList); 
-      
-  }
+    }
   else
-     {
+    {
       if (!mapList->isVisible() )
 	{
 	  mapList->show();
@@ -561,9 +560,10 @@ void knetfilter::setpolRules(KProcess *, char *data, int len) {
   
   if(lines.count()>0){
     polBox->insertStrList(&lines);
-    polBox->insertItem(remainder.data());
-    polBox->setTopItem(polBox->count()-polBox->numItemsVisible()); 
   };
+
+  polBox->insertItem(remainder.data());
+  polBox->setTopItem(polBox->count()-polBox->numItemsVisible()); 
 };
 
 
@@ -597,9 +597,10 @@ void knetfilter::listRules(KProcess *, char *data, int len) {
 
   if(lines.count()>0){
     masqBox->insertStrList(&lines);
-    masqBox->insertItem(remainder.data());
-    masqBox->setTopItem(masqBox->count()-masqBox->numItemsVisible());
   };
+
+  masqBox->insertItem(remainder.data());
+  masqBox->setTopItem(masqBox->count()-masqBox->numItemsVisible());
 };
 
 
@@ -632,11 +633,12 @@ void knetfilter::listDump(KProcess *, char *data, int len) {
   };
 
   if(lines.count()>0) 
-    dumpBox->insertStrList(&lines);
-
- dumpBox->insertItem(remainder.data());
- dumpBox->setTopItem(dumpBox->count()-dumpBox->numItemsVisible());
+    {
+      dumpBox->insertStrList(&lines);
+    };
 
+  dumpBox->insertItem(remainder.data());
+  dumpBox->setTopItem(dumpBox->count()-dumpBox->numItemsVisible());
 };
 
 void knetfilter::portDump(KProcess *, char *data, int len) {
@@ -667,11 +669,13 @@ void knetfilter::portDump(KProcess *, char *data, int len) {
   };
 
   if(lines.count()>0) 
-    mapBox->insertStrList(&lines);
-
- mapBox->insertItem(remainder.data());
- mapBox->setTopItem(mapBox->count()-mapBox->numItemsVisible());
+    {
+      mapBox->insertStrList(&lines);
+    }
 
+  mapBox->insertItem(remainder.data());
+  mapBox->setTopItem(mapBox->count()-mapBox->numItemsVisible());
+    
 };
   
 // probe interface action
@@ -1153,9 +1157,10 @@ void knetfilter::userEntries(KProcess *, char *data, int len) {
 
   if(lines.count()>0){ 
     masqBox->insertStrList(&lines);
-    masqBox->insertItem(remainder.data());
-    masqBox->setTopItem(masqBox->count()-masqBox->numItemsVisible());
   };
+
+  masqBox->insertItem(remainder.data());
+  masqBox->setTopItem(masqBox->count()-masqBox->numItemsVisible());
 };
 
 
