@@ -1,6 +1,6 @@
-  /*
+/*
 
-  knat v 2.1.3
+  knat v 2.2.0
 
   Copyright (C) 2001 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -37,6 +37,9 @@ knetfilter::knetfilter( QWidget *, const char *name )
     masqinterfaceChoice = "eth";
     masqinterfacenrChoice = 0;
     masqinterfacenrChoicedmp = "0";
+    shaperinterfaceChoice = "eth";
+    shaperinterfacenrChoice = 0;
+    shaperinterfacenrChoicedmp = "0";
     chainChoice = "INPUT";
     stateChoice = "nostate";
     policyChoice = "DROP";
@@ -67,6 +70,9 @@ knetfilter::knetfilter( QWidget *, const char *name )
     log2="-v";
     log3="-v";
     tcpmssChoice="FORWARD";
+    qdisc_exec=0;
+    class_exec=0;
+    subclass_exec=0;
 	
     setupMenuBar();
     setupToolBar();
@@ -97,6 +103,7 @@ knetfilter::knetfilter( QWidget *, const char *name )
     mapList = NULL;
     masqWin = NULL;
     tcpmssList = NULL;
+    shaperList = NULL;
 };
 
 
@@ -130,6 +137,33 @@ void knetfilter::setupMenuBar() {
   masqcheck = 0;
 -------------------------------*/
 
+  FILE *tc;
+  FILE *tc2;
+  FILE *tc3;
+  FILE *tc4;
+  FILE *tc5;
+  FILE *tc6;
+
+  tc = fopen("/sbin/tc", "r");
+  tc2 = fopen("/bin/tc", "r");
+  tc3 = fopen("/usr/sbin/tc", "r");
+  tc4 = fopen("/bin/tc", "r");
+  tc5 = fopen("/usr/local/sbin/tc", "r");
+  tc6 = fopen("/usr/local/sbin/sbin/tc", "r");
+  
+  /*
+   * Check if we have tc
+   */
+  if (tc==NULL && tc2==NULL && tc3==NULL && tc4==NULL && tc5==NULL && tc6==NULL)
+    {
+      system_has_tc = 0;
+    }
+  else
+    {
+      system_has_tc = 1;
+    }
+
+ 
   file->insertItem(i18n("&Save all rules"), 
   				this, SLOT(saveAll()));
   file->insertItem(i18n("&Load all rules"), 
@@ -190,6 +224,12 @@ void knetfilter::setupMenuBar() {
   options->insertSeparator();
   options->insertItem(i18n("List Rules, Masquerading & Mangle entries"),
   				this, SLOT(iptablesRules()));
+  if ( system_has_tc == 1 )
+    {
+      options->insertSeparator();
+      options->insertItem(i18n("Traffic Shaper"),
+			            this, SLOT(trafficShaper()));
+    }
   options->insertSeparator();
   options->insertItem(i18n("TcpDump"),
   				this, SLOT(tcpDump()));
@@ -252,10 +292,10 @@ void knetfilter::setupToolBar() {
   toolbar->insertButton("stop_icmp.xpm",del,SIGNAL(clicked()),
 			this,SLOT(delRule_icmp()),TRUE,i18n("Delete rule to icmp"));
   toolbar->insertSeparator();
-  toolbar->insertButton("mark.xpm",del,SIGNAL(clicked()),
+  toolbar->insertButton("mark.xpm",add,SIGNAL(clicked()),
 			this,SLOT(markRules()),TRUE,i18n("Set Up Mark based rules"));
   toolbar->insertSeparator();
-  toolbar->insertButton("probe.xpm",del,SIGNAL(clicked()),
+  toolbar->insertButton("probe.xpm",add,SIGNAL(clicked()),
 			this,SLOT(startprobeInterface()),TRUE,i18n("Probe Network Interface"));
   toolbar->setBarPos( KToolBar::Top );
 
